#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'octave-dock-widget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/octave-dock-widget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'octave-dock-widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__label_dock_widget_t {
    QByteArrayData data[6];
    char stringdata0[74];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__label_dock_widget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__label_dock_widget_t qt_meta_stringdata_octave__label_dock_widget = {
    {
QT_MOC_LITERAL(0, 0, 25), // "octave::label_dock_widget"
QT_MOC_LITERAL(1, 26, 13), // "copyClipboard"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 14), // "pasteClipboard"
QT_MOC_LITERAL(4, 56, 9), // "selectAll"
QT_MOC_LITERAL(5, 66, 7) // "do_undo"

    },
    "octave::label_dock_widget\0copyClipboard\0"
    "\0pasteClipboard\0selectAll\0do_undo"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__label_dock_widget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x09 /* Protected */,
       3,    0,   35,    2, 0x09 /* Protected */,
       4,    0,   36,    2, 0x09 /* Protected */,
       5,    0,   37,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::label_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        label_dock_widget *_t = static_cast<label_dock_widget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->copyClipboard(); break;
        case 1: _t->pasteClipboard(); break;
        case 2: _t->selectAll(); break;
        case 3: _t->do_undo(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject octave::label_dock_widget::staticMetaObject = {
    { &QDockWidget::staticMetaObject, qt_meta_stringdata_octave__label_dock_widget.data,
      qt_meta_data_octave__label_dock_widget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::label_dock_widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::label_dock_widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__label_dock_widget.stringdata0))
        return static_cast<void*>(this);
    return QDockWidget::qt_metacast(_clname);
}

int octave::label_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
struct qt_meta_stringdata_octave__octave_dock_widget_t {
    QByteArrayData data[39];
    char stringdata0[515];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__octave_dock_widget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__octave_dock_widget_t qt_meta_stringdata_octave__octave_dock_widget = {
    {
QT_MOC_LITERAL(0, 0, 26), // "octave::octave_dock_widget"
QT_MOC_LITERAL(1, 27, 14), // "active_changed"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 6), // "active"
QT_MOC_LITERAL(4, 50, 17), // "queue_make_window"
QT_MOC_LITERAL(5, 68, 18), // "widget_was_dragged"
QT_MOC_LITERAL(6, 87, 17), // "queue_make_widget"
QT_MOC_LITERAL(7, 105, 17), // "interpreter_event"
QT_MOC_LITERAL(8, 123, 12), // "fcn_callback"
QT_MOC_LITERAL(9, 136, 3), // "fcn"
QT_MOC_LITERAL(10, 140, 13), // "meth_callback"
QT_MOC_LITERAL(11, 154, 4), // "meth"
QT_MOC_LITERAL(12, 159, 8), // "activate"
QT_MOC_LITERAL(13, 168, 17), // "handle_visibility"
QT_MOC_LITERAL(14, 186, 7), // "visible"
QT_MOC_LITERAL(15, 194, 15), // "notice_settings"
QT_MOC_LITERAL(16, 210, 19), // "const gui_settings*"
QT_MOC_LITERAL(17, 230, 15), // "handle_settings"
QT_MOC_LITERAL(18, 246, 26), // "handle_active_dock_changed"
QT_MOC_LITERAL(19, 273, 19), // "octave_dock_widget*"
QT_MOC_LITERAL(20, 293, 8), // "main_win"
QT_MOC_LITERAL(21, 302, 12), // "QMainWindow*"
QT_MOC_LITERAL(22, 315, 13), // "save_settings"
QT_MOC_LITERAL(23, 329, 9), // "moveEvent"
QT_MOC_LITERAL(24, 339, 11), // "QMoveEvent*"
QT_MOC_LITERAL(25, 351, 5), // "event"
QT_MOC_LITERAL(26, 357, 11), // "resizeEvent"
QT_MOC_LITERAL(27, 369, 13), // "QResizeEvent*"
QT_MOC_LITERAL(28, 383, 11), // "make_window"
QT_MOC_LITERAL(29, 395, 11), // "make_widget"
QT_MOC_LITERAL(30, 407, 8), // "not_used"
QT_MOC_LITERAL(31, 416, 12), // "default_dock"
QT_MOC_LITERAL(32, 429, 15), // "toplevel_change"
QT_MOC_LITERAL(33, 445, 25), // "handle_visibility_changed"
QT_MOC_LITERAL(34, 471, 11), // "eventFilter"
QT_MOC_LITERAL(35, 483, 3), // "obj"
QT_MOC_LITERAL(36, 487, 7), // "QEvent*"
QT_MOC_LITERAL(37, 495, 1), // "e"
QT_MOC_LITERAL(38, 497, 17) // "change_visibility"

    },
    "octave::octave_dock_widget\0active_changed\0"
    "\0active\0queue_make_window\0widget_was_dragged\0"
    "queue_make_widget\0interpreter_event\0"
    "fcn_callback\0fcn\0meth_callback\0meth\0"
    "activate\0handle_visibility\0visible\0"
    "notice_settings\0const gui_settings*\0"
    "handle_settings\0handle_active_dock_changed\0"
    "octave_dock_widget*\0main_win\0QMainWindow*\0"
    "save_settings\0moveEvent\0QMoveEvent*\0"
    "event\0resizeEvent\0QResizeEvent*\0"
    "make_window\0make_widget\0not_used\0"
    "default_dock\0toplevel_change\0"
    "handle_visibility_changed\0eventFilter\0"
    "obj\0QEvent*\0e\0change_visibility"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__octave_dock_widget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      24,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  134,    2, 0x06 /* Public */,
       4,    1,  137,    2, 0x06 /* Public */,
       6,    0,  140,    2, 0x06 /* Public */,
       7,    1,  141,    2, 0x06 /* Public */,
       7,    1,  144,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,  147,    2, 0x0a /* Public */,
      13,    1,  148,    2, 0x0a /* Public */,
      15,    1,  151,    2, 0x0a /* Public */,
      17,    1,  154,    2, 0x0a /* Public */,
      18,    2,  157,    2, 0x0a /* Public */,
      20,    0,  162,    2, 0x0a /* Public */,
      22,    0,  163,    2, 0x0a /* Public */,
      23,    1,  164,    2, 0x0a /* Public */,
      26,    1,  167,    2, 0x0a /* Public */,
      28,    1,  170,    2, 0x0a /* Public */,
      28,    0,  173,    2, 0x2a /* Public | MethodCloned */,
      29,    1,  174,    2, 0x0a /* Public */,
      29,    0,  177,    2, 0x2a /* Public | MethodCloned */,
      31,    1,  178,    2, 0x0a /* Public */,
      31,    0,  181,    2, 0x2a /* Public | MethodCloned */,
      32,    1,  182,    2, 0x09 /* Protected */,
      33,    1,  185,    2, 0x09 /* Protected */,
      34,    2,  188,    2, 0x09 /* Protected */,
      38,    1,  193,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 10,   11,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 19, 0x80000000 | 19,    2,    2,
    0x80000000 | 21,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 24,   25,
    QMetaType::Void, 0x80000000 | 27,   25,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 36,   35,   37,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void octave::octave_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        octave_dock_widget *_t = static_cast<octave_dock_widget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->active_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->queue_make_window((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->queue_make_widget(); break;
        case 3: _t->interpreter_event((*reinterpret_cast< const fcn_callback(*)>(_a[1]))); break;
        case 4: _t->interpreter_event((*reinterpret_cast< const meth_callback(*)>(_a[1]))); break;
        case 5: _t->activate(); break;
        case 6: _t->handle_visibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
        case 8: _t->handle_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
        case 9: _t->handle_active_dock_changed((*reinterpret_cast< octave_dock_widget*(*)>(_a[1])),(*reinterpret_cast< octave_dock_widget*(*)>(_a[2]))); break;
        case 10: { QMainWindow* _r = _t->main_win();
            if (_a[0]) *reinterpret_cast< QMainWindow**>(_a[0]) = std::move(_r); }  break;
        case 11: _t->save_settings(); break;
        case 12: _t->moveEvent((*reinterpret_cast< QMoveEvent*(*)>(_a[1]))); break;
        case 13: _t->resizeEvent((*reinterpret_cast< QResizeEvent*(*)>(_a[1]))); break;
        case 14: _t->make_window((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->make_window(); break;
        case 16: _t->make_widget((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->make_widget(); break;
        case 18: _t->default_dock((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->default_dock(); break;
        case 20: _t->toplevel_change((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->handle_visibility_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: { bool _r = _t->eventFilter((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QEvent*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->change_visibility((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< octave_dock_widget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (octave_dock_widget::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_dock_widget::active_changed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (octave_dock_widget::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_dock_widget::queue_make_window)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (octave_dock_widget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_dock_widget::queue_make_widget)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (octave_dock_widget::*_t)(const fcn_callback & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_dock_widget::interpreter_event)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (octave_dock_widget::*_t)(const meth_callback & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_dock_widget::interpreter_event)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject octave::octave_dock_widget::staticMetaObject = {
    { &label_dock_widget::staticMetaObject, qt_meta_stringdata_octave__octave_dock_widget.data,
      qt_meta_data_octave__octave_dock_widget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::octave_dock_widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::octave_dock_widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__octave_dock_widget.stringdata0))
        return static_cast<void*>(this);
    return label_dock_widget::qt_metacast(_clname);
}

int octave::octave_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = label_dock_widget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void octave::octave_dock_widget::active_changed(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void octave::octave_dock_widget::queue_make_window(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void octave::octave_dock_widget::queue_make_widget()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void octave::octave_dock_widget::interpreter_event(const fcn_callback & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void octave::octave_dock_widget::interpreter_event(const meth_callback & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
